/*
 * screenload - loads SUN rasterfiles onto the ABC1600 console screen
 *
 * usage:
 *       screenload [filename]
 *
 * If no filename is provided data is read from standard input.
 *
 * Only binary images in standard format is supported yet, i.e. no colours,
 * greyscales or run length encoded images.
 */
 
#include <stdio.h>
#include <abc1600/picture.h>
#include <dnix/fcodes.h>
#include "rasterfile.h"         /* File pinched from SUN */


scrload(fp)
FILE *fp;
{
    pictblk *picmem;
    struct rasterfile rf;
    int i, l, start;
    
    puts("\33:0;0m\33:767;1023;0;0f");
    fread(&rf,sizeof(struct rasterfile),1,fp);
    if(rf.ras_type!=RT_STANDARD && rf.ras_type!=RT_OLD)
        return -1;   /* Only standard files supported yet. */
    if(rf.ras_depth!=1)
	    return -1;   /* No greyscales or colors supported yet */
    l=rf.ras_length/rf.ras_height;
    picmem=(pictblk *)malloc(l+50);
    picmem->p_magic=65534;
    picmem->p_xaddr=(768-rf.ras_width)/2;
    if(picmem->p_xaddr<0)
        picmem->p_xaddr=0;
    picmem->p_width=l;
    if(l>768)
        picmem->p_width=768;
    picmem->p_height=1;
    start=1023-(1024-rf.ras_height)/2;
    for(i=start;i>start-rf.ras_height;i--){
        picmem->p_yaddr=i;
        fread((((char *)picmem)+50),l,1,fp);
        pwrite(1,picmem,picmem->p_width);
    }
}


main(argc, argv)
int argc;
char *argv[];
{
    FILE *infile;

    if (argc == 1) {
        infile = stdin;
    } else if ((infile = fopen(argv[1], "r")) == 0) {
	exit(1);
    }
    scrload(infile);
}

